<!doctype html>
<html>
  <head>
    <meta charset="UTF-8" />
    <title>Scatter Plot of Iris Dataset</title>
    <link rel="stylesheet" href="styles.css" />
    <script src="https://d3js.org/d3.v7.min.js"></script>
  </head>
  <body>
    <h1>Scatter Plot for Sepal Length Versus Sepal Width</h1>
    <script>
      const { csv, select, scaleLinear, extent, axisLeft, axisBottom } = d3;
      const csvUrl =
        'https://gist.githubusercontent.com/kusuma63663/e187e16328098b8ef46605054283ccde/raw/d1a8d22312201e6362ff0fa79101fcba09bfec2f/WHO-COVID-19-global-data.csv';

      const parseRow = (d) => {
        d['SepalLength'] = +d['SepalLength'];
        d['SepalWidth'] = +d['SepalWidth'];
        return d;
      };

      const xValue = (d) => d['SepalLength'];
      const yValue = (d) => d['SepalWidth'];

      const margin = { top: 30, right: 50, bottom: 100, left: 250 };
      const radius = 7;
      const width = 960; // Adjust the width to fit in the frame
      const height = 550; // Adjust the height to fit in the frame

      const svg = select('body')
        .append('svg')
        .attr('width', width)
        .attr('height', height);

      const main = async () => {
        const data = await csv(csvUrl, parseRow);

        const x = scaleLinear()
          .domain(extent(data, xValue))
          .range([margin.left, width - margin.right]);

        const y = scaleLinear()
          .domain(extent(data, yValue))
          .range([height - margin.bottom, margin.top]);

        svg
          .selectAll('circle')
          .data(data)
          .join('circle')
          .attr('cx', (d) => x(xValue(d)))
          .attr('cy', (d) => y(yValue(d)))
          .attr('r', radius)
          .attr('stroke', '#fbeec1')
          .attr('fill', '#bc986a');

        svg
          .append('g')
          .attr('transform', `translate(${margin.left},0)`)
          .call(axisLeft(y));

        svg
          .append('text')
          .attr('class', 'axis-label')
          .attr('x', -height / 2)
          .attr('y', 160)
          .attr('fill', 'black')
          .style('font', '30px poppins')
          .style('text-anchor', 'middle')
          .attr('transform', `rotate(-90)`)
          .text('Sepal Width');

        svg
          .append('g')
          .attr('transform', `translate(0,${height - margin.bottom})`)
          .call(axisBottom(x));

        svg
          .append('text')
          .attr('class', 'axis-label')
          .attr('x', width / 2)
          .attr('y', height - 30)
          .attr('fill', 'black')
          .style('font', '30px poppins')
          .style('text-anchor', 'middle')
          .text('Sepal Length');
      };
      main();
    </script>
  </body>
</html>
